import app.landscape
import haproxy

from app.scripts import BaseConfigScript

class ConfigScript(BaseConfigScript):

    def configSnippet(self):
        backendMachines = haproxy.HaproxyCluster.get().getBackendMachines("haproxy-ctfcore")
        
        # Mark first server as active, rest as backup.
        config = []
        for m in sorted(backendMachines, key=lambda m: m.getPhysicalName()):
            # 'check' enables the health check
            # 'check-ssl' causes the health check to be run via SSL
            # 'verify none' causes SSL certificate validation to be skipped
        
            config.append("\tserver %s %s:443 ssl check check-ssl %s verify none on-marked-down shutdown-sessions" % (
                m.getPhysicalAddress().getName(), 
                m.getPhysicalAddress().getIp(),
                "backup" if len(config) > 0 else ""))
            
        return "\n".join(config)