﻿import os
import signal
import time
import app.servicecontrol
import app.linuxservice
import urllib2
import sys

class ServiceController(app.servicecontrol.ServiceController):
    def getPidFile(self):
        return "/var/run/syslogd.pid"

    def canBootstrap(self):
        # Bootstrapping syslogd is a no-op, so allow it always.
        return True

    def startDaemonAsync(self):
        if app.linuxservice.ServiceManager.isAvailable():
            return app.linuxservice.ServiceManager.getService("rsyslog", self.logger).start()
        else:
            return app.util.runSystem("rsyslogd > /dev/null", self.logger, skip_error=True)

    def stopDaemonAsync(self):
        if app.linuxservice.ServiceManager.isAvailable():
            return app.linuxservice.ServiceManager.getService("rsyslog", self.logger).stop()
        else:
            return app.util.runSystem("pkill rsyslogd > /dev/null", self.logger, skip_error=True)

    def createPostDeployAction(self):
        # Start the service right after deployment
        return RestartRsyslogAction(self.getService(), self.logger)

class RestartRsyslogAction(app.servicecontrol.ControllerAction):
    def __init__(self, service, logger):
        self.__service = service
        super(RestartRsyslogAction, self).__init__(logger)

    def getInvolvedServices(self):
        return [self.__service]

    def confirm(self, isRedeployment=False):
        return True

    def execute(self):
        import app.actions.stop
        import app.actions.start

        return app.actions.stop.StopServiceAction([self.__service], self.logger).execute() and \
               app.actions.start.StartServiceAction([self.__service], self.logger).execute()
    
    def getLogPaths(self):
        return [os.path.join(app.util.getRuntimeConfiguration().get("HAPROXY_RSYSLOG_LOG_DIR"), "*")]